NyxPrinter class
Properties
hashCode
→ int
The hash code for this object.
no setter inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
Methods
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString ()
→ String
A string representation of this object.
inherited
Static Methods
clearLabelLearning ()
→ Future <void >
Clear label learning data
configLcd (LcdOpt opt )
→ Future <void >
Control the status of the customer display LCD
PrinterService >= v1.6.3
getPrinterDensity ()
→ Future <int ? >
Get printer density
PrinterService >= v1.9.2
getPrinterStatus ()
→ Future <int ? >
get printer status PrinterStatus
getPrinterVersion ()
→ Future <String ? >
get printer firmware version
getServiceVersion ()
→ Future <String ? >
get printer service version
hasLabelLearning ()
→ Future <void >
Label learning has been performed
labelDetectAuto ()
→ Future <void >
Label learning by automatic label detection.
This method will start label learning
labelLocate (int labelHeight , int labelGap )
→ Future <void >
Locate the next label
labelLocateAuto ({int labelHeight = 0 , int labelGap = 0 })
→ Future <void >
Auto locate label. This method only can be called on the system that has
performed abel learning by labelDetectAuto
labelPrintEnd ()
→ Future <void >
Label printing ends, paper automatically moves to the tear-off position.
This method must appear in pairs with labelLocate
openCashBox ()
→ Future <void >
Open cash drawer
PrinterService >= v1.6.1
paperBack (int px )
→ Future <void >
paperOut (int px )
→ Future <void >
printBarcode (String data , int width , int height , {BarcodeTextPosition textPosition = BarcodeTextPosition.NO_TEXT , PrintAlign align = PrintAlign.LEFT , BarcodeSymbology symbology = BarcodeSymbology.CODE128 })
→ Future <void >
printEndAutoOut ()
→ Future <void >
After printing, feed paper to cutting position
printEscposData (Uint8List data )
→ Future <Uint8List ? >
Print ESC/POS commands
PrinterService v1.5.9 support ESC commands with responses, such as GS r, ESC v, etc.
printImage (Uint8List img , {ImageType type = ImageType.BLACK_WHITE , PrintAlign align = PrintAlign.LEFT })
→ Future <void >
printQrCode (String data , int width , int height , {PrintAlign align = PrintAlign.LEFT })
→ Future <void >
printRasterData (Uint8List data )
→ Future <void >
Print raster bitmap data
printTableText (List <String > texts , List <int > weights , List <PrintTextStyle > styles )
→ Future <void >
Print a row of a table
printText (String text , PrintTextStyle ? style , {int ? textWidth , PrintAlign ? align })
→ Future <void >
setLcdLogo (Uint8List img )
→ Future <void >
Set default logo for customer display LCD
It is recommended not to change the logo frequently. The number of modifications is less than 5000 times
PrinterService version >= v1.7.9
setPaperWidth (int width )
→ Future <void >
Set paper width. Primarily used for printing 58mm paper on 80mm printer.
width Paper width
58mm: 384
80mm: 384/576
PrinterService >= v2.0.5
setPrinterDensity (int density )
→ Future <void >
Set printer density
58mm: 80/90/100/110/120/130
80mm: 100/110/120/130
showLcdImage (Uint8List img )
→ Future <void >
Show bitmap in customer display LCD
PrinterService version >= v1.5.9 only support black-white bitmap
PrinterService version >= v1.7.6 support colored bitmap automatic conversion
nyx_printer_flutter 1.0.2